@@ -10,8 +10,10 @@ import logging
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseBadRequest, \
   HttpResponseForbidden, HttpResponseRedirect
+from django.views.decorators.cache import cache_page, never_cache
 from django.views.decorators.csrf import csrf_exempt
 from django.views.decorators.http import require_http_methods
+from django.views.decorators.vary import vary_on_cookie
 
 from sentry.conf import settings
 from sentry.exceptions import InvalidData
@@ -23,7 +25,7 @@ from sentry.utils import json
 from sentry.utils.http import is_same_domain, apply_access_control_headers
 from sentry.web.decorators import has_access
 from sentry.web.frontend.groups import _get_group_list
-from sentry.web.helpers import render_to_response, render_to_string
+from sentry.web.helpers import render_to_response, render_to_string, get_project_list
 
 error_logger = logging.getLogger('sentry.errors.api.http')
 logger = logging.getLogger('sentry.api.http')
@@ -31,6 +33,7 @@ logger = logging.getLogger('sentry.api.http')
 
 @csrf_exempt
 @require_http_methods(['POST', 'OPTIONS'])
+@never_cache
 def store(request, project_id=None):
     """
     The primary endpoint for storing new events.
@@ -144,12 +147,14 @@ def store(request, project_id=None):
 
 @csrf_exempt
 @has_access
+@never_cache
 def notification(request, project):
     return render_to_response('sentry/partial/_notification.html', request.GET)
 
 
 @csrf_exempt
 @has_access
+@never_cache
 def poll(request, project):
     from sentry.templatetags.sentry_helpers import as_bookmarks
     from sentry.templatetags.sentry_plugins import handle_before_events
@@ -199,6 +204,7 @@ def poll(request, project):
 
 @csrf_exempt
 @has_access
+@never_cache
 def resolve(request, project):
     gid = request.REQUEST.get('gid')
     if not gid:
@@ -227,6 +233,7 @@ def resolve(request, project):
 
 @csrf_exempt
 @has_access
+@never_cache
 def remove_group(request, project, group_id):
     try:
         group = Group.objects.get(pk=group_id)
@@ -245,6 +252,7 @@ def remove_group(request, project, group_id):
 
 @csrf_exempt
 @has_access
+@never_cache
 def bookmark(request, project):
     gid = request.REQUEST.get('gid')
     if not gid:
@@ -273,6 +281,7 @@ def bookmark(request, project):
 
 @csrf_exempt
 @has_access
+@never_cache
 def clear(request, project):
     view_id = request.GET.get('view_id')
     if view_id:
@@ -298,9 +307,11 @@ def clear(request, project):
     return response
 
 
+@vary_on_cookie
+@cache_page(60 * 5)
 @csrf_exempt
 @has_access
-def chart(request, project):
+def chart(request, project=None):
     gid = request.REQUEST.get('gid')
     days = int(request.REQUEST.get('days', '90'))
 
@@ -311,8 +322,11 @@ def chart(request, project):
             return HttpResponseForbidden()
 
         data = Group.objects.get_chart_data(group, max_days=days)
-    else:
+    elif project:
         data = Project.objects.get_chart_data(project, max_days=days)
+    else:
+        project_list = get_project_list(request.user).values()
+        data = Project.objects.get_chart_data_for_group(project_list, max_days=days)
 
     response = HttpResponse(json.dumps(data))
     response['Content-Type'] = 'application/json'
